@@ -143,12 +143,6 @@ pixbuf_document_class_init (PixbufDocumentClass *klass)
 	gobject_class->finalize = pixbuf_document_finalize;
 }
 
-static gboolean
-pixbuf_document_can_get_text (EvDocument *document)
-{
-	return FALSE;
-}
-
 static EvDocumentInfo *
 pixbuf_document_get_info (EvDocument *document)
 {
@@ -165,7 +159,6 @@ pixbuf_document_document_iface_init (EvDocumentIface *iface)
 {
 	iface->load = pixbuf_document_load;
 	iface->save = pixbuf_document_save;
-	iface->can_get_text = pixbuf_document_can_get_text;
 	iface->get_n_pages = pixbuf_document_get_n_pages;
 	iface->get_page_size = pixbuf_document_get_page_size;
 	iface->render = pixbuf_document_render;
